# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feast/core/Feature.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from feast.types import Value_pb2 as feast_dot_types_dot_Value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x66\x65\x61st/core/Feature.proto\x12\nfeast.core\x1a\x17\x66\x65\x61st/types/Value.proto\"\xb0\x01\n\x0b\x46\x65\x61tureSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\nvalue_type\x18\x02 \x01(\x0e\x32\x1b.feast.types.ValueType.Enum\x12\x33\n\x06labels\x18\x03 \x03(\x0b\x32#.feast.core.FeatureSpec.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42.\n\x1e\x64\x65v.caraml.store.protobuf.coreB\x0c\x46\x65\x61tureProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feast.core.Feature_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036dev.caraml.store.protobuf.coreB\014FeatureProto'
  _FEATURESPEC_LABELSENTRY._options = None
  _FEATURESPEC_LABELSENTRY._serialized_options = b'8\001'
  _FEATURESPEC._serialized_start=66
  _FEATURESPEC._serialized_end=242
  _FEATURESPEC_LABELSENTRY._serialized_start=197
  _FEATURESPEC_LABELSENTRY._serialized_end=242
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from feast_spark.api import JobService_pb2 as feast__spark_dot_api_dot_JobService__pb2


class JobServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartOfflineToOnlineIngestionJob = channel.unary_unary(
                '/feast.core.JobService/StartOfflineToOnlineIngestionJob',
                request_serializer=feast__spark_dot_api_dot_JobService__pb2.StartOfflineToOnlineIngestionJobRequest.SerializeToString,
                response_deserializer=feast__spark_dot_api_dot_JobService__pb2.StartOfflineToOnlineIngestionJobResponse.FromString,
                )
        self.GetHistoricalFeatures = channel.unary_unary(
                '/feast.core.JobService/GetHistoricalFeatures',
                request_serializer=feast__spark_dot_api_dot_JobService__pb2.GetHistoricalFeaturesRequest.SerializeToString,
                response_deserializer=feast__spark_dot_api_dot_JobService__pb2.GetHistoricalFeaturesResponse.FromString,
                )
        self.GetJob = channel.unary_unary(
                '/feast.core.JobService/GetJob',
                request_serializer=feast__spark_dot_api_dot_JobService__pb2.GetJobRequest.SerializeToString,
                response_deserializer=feast__spark_dot_api_dot_JobService__pb2.GetJobResponse.FromString,
                )


class JobServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StartOfflineToOnlineIngestionJob(self, request, context):
        """Start job to ingest data from offline store into online store
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHistoricalFeatures(self, request, context):
        """Produce a training dataset, return a job id that will provide a file reference
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJob(self, request, context):
        """Get details of a single job
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StartOfflineToOnlineIngestionJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StartOfflineToOnlineIngestionJob,
                    request_deserializer=feast__spark_dot_api_dot_JobService__pb2.StartOfflineToOnlineIngestionJobRequest.FromString,
                    response_serializer=feast__spark_dot_api_dot_JobService__pb2.StartOfflineToOnlineIngestionJobResponse.SerializeToString,
            ),
            'GetHistoricalFeatures': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHistoricalFeatures,
                    request_deserializer=feast__spark_dot_api_dot_JobService__pb2.GetHistoricalFeaturesRequest.FromString,
                    response_serializer=feast__spark_dot_api_dot_JobService__pb2.GetHistoricalFeaturesResponse.SerializeToString,
            ),
            'GetJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJob,
                    request_deserializer=feast__spark_dot_api_dot_JobService__pb2.GetJobRequest.FromString,
                    response_serializer=feast__spark_dot_api_dot_JobService__pb2.GetJobResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'feast.core.JobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class JobService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StartOfflineToOnlineIngestionJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.JobService/StartOfflineToOnlineIngestionJob',
            feast__spark_dot_api_dot_JobService__pb2.StartOfflineToOnlineIngestionJobRequest.SerializeToString,
            feast__spark_dot_api_dot_JobService__pb2.StartOfflineToOnlineIngestionJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHistoricalFeatures(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.JobService/GetHistoricalFeatures',
            feast__spark_dot_api_dot_JobService__pb2.GetHistoricalFeaturesRequest.SerializeToString,
            feast__spark_dot_api_dot_JobService__pb2.GetHistoricalFeaturesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.JobService/GetJob',
            feast__spark_dot_api_dot_JobService__pb2.GetJobRequest.SerializeToString,
            feast__spark_dot_api_dot_JobService__pb2.GetJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feast_spark/api/JobService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from feast.core import DataSource_pb2 as feast_dot_core_dot_DataSource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n feast_spark/api/JobService.proto\x12\x0f\x66\x65\x61st_spark.api\x1a\x1b\x66\x65\x61st/core/DataSource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9b\x04\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x18.feast_spark.api.JobType\x12*\n\x06status\x18\x03 \x01(\x0e\x32\x1a.feast_spark.api.JobStatus\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\tretrieval\x18\x06 \x01(\x0b\x32%.feast_spark.api.Job.RetrievalJobMetaH\x00\x12\x43\n\x0f\x62\x61tch_ingestion\x18\x07 \x01(\x0b\x32(.feast_spark.api.Job.OfflineToOnlineMetaH\x00\x12\x43\n\x10stream_ingestion\x18\x08 \x01(\x0b\x32\'.feast_spark.api.Job.StreamToOnlineMetaH\x00\x12\x0f\n\x07log_uri\x18\t \x01(\t\x12\x15\n\rerror_message\x18\n \x01(\t\x1a+\n\x10RetrievalJobMeta\x12\x17\n\x0foutput_location\x18\x01 \x01(\t\x1a)\n\x13OfflineToOnlineMeta\x12\x12\n\ntable_name\x18\x01 \x01(\t\x1a(\n\x12StreamToOnlineMeta\x12\x12\n\ntable_name\x18\x01 \x01(\tB\x06\n\x04meta\"\xc5\x01\n\'StartOfflineToOnlineIngestionJobRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12.\n\nstart_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x64\x65lta_ingestion\x18\x05 \x01(\x08\"\x8f\x01\n(StartOfflineToOnlineIngestionJobResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x0ejob_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x0f\n\x07log_uri\x18\x04 \x01(\t\"\x84\x01\n*ScheduleOfflineToOnlineIngestionJobRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x1a\n\x12ingestion_timespan\x18\x03 \x01(\x05\x12\x15\n\rcron_schedule\x18\x04 \x01(\t\"-\n+ScheduleOfflineToOnlineIngestionJobResponse\"S\n,UnscheduleOfflineToOnlineIngestionJobRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ntable_name\x18\x02 \x01(\t\"/\n-UnscheduleOfflineToOnlineIngestionJobResponse\"\xa4\x01\n\x1cGetHistoricalFeaturesRequest\x12\x14\n\x0c\x66\x65\x61ture_refs\x18\x01 \x03(\t\x12-\n\rentity_source\x18\x02 \x01(\x0b\x32\x16.feast.core.DataSource\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x17\n\x0foutput_location\x18\x04 \x01(\t\x12\x15\n\routput_format\x18\x05 \x01(\t\"\x89\x01\n\x1dGetHistoricalFeaturesResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0foutput_file_uri\x18\x02 \x01(\t\x12\x32\n\x0ejob_start_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07log_uri\x18\x04 \x01(\t\"R\n\x0fListJobsRequest\x12\x1a\n\x12include_terminated\x18\x01 \x01(\x08\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\"6\n\x10ListJobsResponse\x12\"\n\x04jobs\x18\x01 \x03(\x0b\x32\x14.feast_spark.api.Job\"\x1f\n\rGetJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"3\n\x0eGetJobResponse\x12!\n\x03job\x18\x01 \x01(\x0b\x32\x14.feast_spark.api.Job\"\"\n\x10\x43\x61ncelJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x13\n\x11\x43\x61ncelJobResponse\"?\n\x17GetHealthMetricsRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x13\n\x0btable_names\x18\x02 \x03(\t\":\n\x18GetHealthMetricsResponse\x12\x0e\n\x06passed\x18\x01 \x03(\t\x12\x0e\n\x06\x66\x61iled\x18\x02 \x03(\t*`\n\x07JobType\x12\x0f\n\x0bINVALID_JOB\x10\x00\x12\x17\n\x13\x42\x41TCH_INGESTION_JOB\x10\x01\x12\x18\n\x14STREAM_INGESTION_JOB\x10\x02\x12\x11\n\rRETRIEVAL_JOB\x10\x04*~\n\tJobStatus\x12\x16\n\x12JOB_STATUS_INVALID\x10\x00\x12\x16\n\x12JOB_STATUS_PENDING\x10\x01\x12\x16\n\x12JOB_STATUS_RUNNING\x10\x02\x12\x13\n\x0fJOB_STATUS_DONE\x10\x03\x12\x14\n\x10JOB_STATUS_ERROR\x10\x04\x32\xc3\x07\n\nJobService\x12\x97\x01\n StartOfflineToOnlineIngestionJob\x12\x38.feast_spark.api.StartOfflineToOnlineIngestionJobRequest\x1a\x39.feast_spark.api.StartOfflineToOnlineIngestionJobResponse\x12\xa0\x01\n#ScheduleOfflineToOnlineIngestionJob\x12;.feast_spark.api.ScheduleOfflineToOnlineIngestionJobRequest\x1a<.feast_spark.api.ScheduleOfflineToOnlineIngestionJobResponse\x12\xa6\x01\n%UnscheduleOfflineToOnlineIngestionJob\x12=.feast_spark.api.UnscheduleOfflineToOnlineIngestionJobRequest\x1a>.feast_spark.api.UnscheduleOfflineToOnlineIngestionJobResponse\x12v\n\x15GetHistoricalFeatures\x12-.feast_spark.api.GetHistoricalFeaturesRequest\x1a..feast_spark.api.GetHistoricalFeaturesResponse\x12O\n\x08ListJobs\x12 .feast_spark.api.ListJobsRequest\x1a!.feast_spark.api.ListJobsResponse\x12R\n\tCancelJob\x12!.feast_spark.api.CancelJobRequest\x1a\".feast_spark.api.CancelJobResponse\x12I\n\x06GetJob\x12\x1e.feast_spark.api.GetJobRequest\x1a\x1f.feast_spark.api.GetJobResponse\x12g\n\x10GetHealthMetrics\x12(.feast_spark.api.GetHealthMetricsRequest\x1a).feast_spark.api.GetHealthMetricsResponseB7\n$dev.caraml.store.protobuf.jobserviceB\x0fJobServiceProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feast_spark.api.JobService_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$dev.caraml.store.protobuf.jobserviceB\017JobServiceProto'
  _JOBTYPE._serialized_start=2034
  _JOBTYPE._serialized_end=2130
  _JOBSTATUS._serialized_start=2132
  _JOBSTATUS._serialized_end=2258
  _JOB._serialized_start=116
  _JOB._serialized_end=655
  _JOB_RETRIEVALJOBMETA._serialized_start=519
  _JOB_RETRIEVALJOBMETA._serialized_end=562
  _JOB_OFFLINETOONLINEMETA._serialized_start=564
  _JOB_OFFLINETOONLINEMETA._serialized_end=605
  _JOB_STREAMTOONLINEMETA._serialized_start=607
  _JOB_STREAMTOONLINEMETA._serialized_end=647
  _STARTOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_start=658
  _STARTOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_end=855
  _STARTOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_start=858
  _STARTOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_end=1001
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_start=1004
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_end=1136
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_start=1138
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_end=1183
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_start=1185
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_end=1268
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_start=1270
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_end=1317
  _GETHISTORICALFEATURESREQUEST._serialized_start=1320
  _GETHISTORICALFEATURESREQUEST._serialized_end=1484
  _GETHISTORICALFEATURESRESPONSE._serialized_start=1487
  _GETHISTORICALFEATURESRESPONSE._serialized_end=1624
  _LISTJOBSREQUEST._serialized_start=1626
  _LISTJOBSREQUEST._serialized_end=1708
  _LISTJOBSRESPONSE._serialized_start=1710
  _LISTJOBSRESPONSE._serialized_end=1764
  _GETJOBREQUEST._serialized_start=1766
  _GETJOBREQUEST._serialized_end=1797
  _GETJOBRESPONSE._serialized_start=1799
  _GETJOBRESPONSE._serialized_end=1850
  _CANCELJOBREQUEST._serialized_start=1852
  _CANCELJOBREQUEST._serialized_end=1886
  _CANCELJOBRESPONSE._serialized_start=1888
  _CANCELJOBRESPONSE._serialized_end=1907
  _GETHEALTHMETRICSREQUEST._serialized_start=1909
  _GETHEALTHMETRICSREQUEST._serialized_end=1972
  _GETHEALTHMETRICSRESPONSE._serialized_start=1974
  _GETHEALTHMETRICSRESPONSE._serialized_end=2032
  _JOBSERVICE._serialized_start=2261
  _JOBSERVICE._serialized_end=3224
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import feast.core.DataSource_pb2
import feast.core.Feature_pb2
import feast.core.OnlineStore_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeatureTable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    @property
    def spec(self) -> global___FeatureTableSpec:
        """User-specified specifications of this feature table."""
    @property
    def meta(self) -> global___FeatureTableMeta:
        """System-populated metadata for this feature table."""
    def __init__(
        self,
        *,
        spec: global___FeatureTableSpec | None = ...,
        meta: global___FeatureTableMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta", b"meta", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["meta", b"meta", "spec", b"spec"]) -> None: ...

global___FeatureTable = FeatureTable

class FeatureTableSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    ENTITIES_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    BATCH_SOURCE_FIELD_NUMBER: builtins.int
    STREAM_SOURCE_FIELD_NUMBER: builtins.int
    STALENESS_THRESHOLD_FIELD_NUMBER: builtins.int
    ONLINE_STORE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the feature table. Must be unique. Not updated."""
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List names of entities to associate with the Features defined in this 
        Feature Table. Not updatable.
        """
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[feast.core.Feature_pb2.FeatureSpec]:
        """List of features specifications for each feature defined with this feature table."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """User defined metadata"""
    @property
    def max_age(self) -> google.protobuf.duration_pb2.Duration:
        """Features in this feature table can only be retrieved from online serving
        younger than max age. Age is measured as the duration of time between 
        the feature's event timestamp and when the feature is retrieved
        Feature values outside max age will be returned as unset values and indicated to end user
        """
    @property
    def batch_source(self) -> feast.core.DataSource_pb2.DataSource:
        """Batch/Offline DataSource to source batch/offline feature data.
        Only batch DataSource can be specified 
        (ie source type should start with 'BATCH_')
        """
    @property
    def stream_source(self) -> feast.core.DataSource_pb2.DataSource:
        """Stream/Online DataSource to source stream/online feature data.
        Only stream DataSource can be specified 
        (ie source type should start with 'STREAM_')
        """
    @property
    def staleness_threshold(self) -> google.protobuf.duration_pb2.Duration:
        """Threshold to detect features that are close to be evicted.
        Used by Feast Serving to indicate that feature is stale.
        Must be less than max_age, since after max_age feature most probably will be garbage collected
        """
    @property
    def online_store(self) -> feast.core.OnlineStore_pb2.OnlineStore:
        """Database where features are stored for online serving"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        entities: collections.abc.Iterable[builtins.str] | None = ...,
        features: collections.abc.Iterable[feast.core.Feature_pb2.FeatureSpec] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        max_age: google.protobuf.duration_pb2.Duration | None = ...,
        batch_source: feast.core.DataSource_pb2.DataSource | None = ...,
        stream_source: feast.core.DataSource_pb2.DataSource | None = ...,
        staleness_threshold: google.protobuf.duration_pb2.Duration | None = ...,
        online_store: feast.core.OnlineStore_pb2.OnlineStore | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_source", b"batch_source", "max_age", b"max_age", "online_store", b"online_store", "staleness_threshold", b"staleness_threshold", "stream_source", b"stream_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_source", b"batch_source", "entities", b"entities", "features", b"features", "labels", b"labels", "max_age", b"max_age", "name", b"name", "online_store", b"online_store", "staleness_threshold", b"staleness_threshold", "stream_source", b"stream_source"]) -> None: ...

global___FeatureTableSpec = FeatureTableSpec

class FeatureTableMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_UPDATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    @property
    def created_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time where this Feature Table is created"""
    @property
    def last_updated_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time where this Feature Table is last updated"""
    revision: builtins.int
    """Auto incrementing revision no. of this Feature Table"""
    hash: builtins.str
    """Hash entities, features, batch_source and stream_source to inform JobService if
    jobs should be restarted should hash change
    """
    def __init__(
        self,
        *,
        created_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_updated_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        revision: builtins.int = ...,
        hash: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_timestamp", b"created_timestamp", "last_updated_timestamp", b"last_updated_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_timestamp", b"created_timestamp", "hash", b"hash", "last_updated_timestamp", b"last_updated_timestamp", "revision", b"revision"]) -> None: ...

global___FeatureTableMeta = FeatureTableMeta



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import feast.types.Value_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FieldStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FieldStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FieldStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID: _FieldStatus.ValueType  # 0
    """Status is unset for this field."""
    PRESENT: _FieldStatus.ValueType  # 1
    """Field value is present for this field and age is within max age."""
    NULL_VALUE: _FieldStatus.ValueType  # 2
    """Values could be found for entity key and age is within max age, but
    this field value is assigned a value on ingestion into feast.
    """
    NOT_FOUND: _FieldStatus.ValueType  # 3
    """Entity key did not return any values as they do not exist in Feast.
    This could suggest that the feature values have not yet been ingested
    into feast or the ingestion failed.
    """
    OUTSIDE_MAX_AGE: _FieldStatus.ValueType  # 4
    """Values could be found for entity key, but field values are outside the maximum
    allowable range.
    """
    INGESTION_FAILURE: _FieldStatus.ValueType  # 5
    """Values could be found for entity key, but are null and is due to ingestion failures"""

class FieldStatus(_FieldStatus, metaclass=_FieldStatusEnumTypeWrapper): ...

INVALID: FieldStatus.ValueType  # 0
"""Status is unset for this field."""
PRESENT: FieldStatus.ValueType  # 1
"""Field value is present for this field and age is within max age."""
NULL_VALUE: FieldStatus.ValueType  # 2
"""Values could be found for entity key and age is within max age, but
this field value is assigned a value on ingestion into feast.
"""
NOT_FOUND: FieldStatus.ValueType  # 3
"""Entity key did not return any values as they do not exist in Feast.
This could suggest that the feature values have not yet been ingested
into feast or the ingestion failed.
"""
OUTSIDE_MAX_AGE: FieldStatus.ValueType  # 4
"""Values could be found for entity key, but field values are outside the maximum
allowable range.
"""
INGESTION_FAILURE: FieldStatus.ValueType  # 5
"""Values could be found for entity key, but are null and is due to ingestion failures"""
global___FieldStatus = FieldStatus

class GetFeastServingInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetFeastServingInfoRequest = GetFeastServingInfoRequest

class GetFeastServingInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Feast version of this serving deployment."""
    def __init__(
        self,
        *,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["version", b"version"]) -> None: ...

global___GetFeastServingInfoResponse = GetFeastServingInfoResponse

class FeatureReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_TABLE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    feature_table: builtins.str
    """Name of the Feature Table to retrieve the feature from."""
    name: builtins.str
    """Name of the Feature to retrieve the feature from."""
    def __init__(
        self,
        *,
        feature_table: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_table", b"feature_table", "name", b"name"]) -> None: ...

global___FeatureReference = FeatureReference

class GetOnlineFeaturesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EntityRow(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class FieldsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            @property
            def value(self) -> feast.types.Value_pb2.Value: ...
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: feast.types.Value_pb2.Value | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        TIMESTAMP_FIELD_NUMBER: builtins.int
        FIELDS_FIELD_NUMBER: builtins.int
        @property
        def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Request timestamp of this row. This value will be used,
            together with maxAge, to determine feature staleness.
            """
        @property
        def fields(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, feast.types.Value_pb2.Value]:
            """Map containing mapping of entity name to entity value."""
        def __init__(
            self,
            *,
            timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            fields: collections.abc.Mapping[builtins.str, feast.types.Value_pb2.Value] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["fields", b"fields", "timestamp", b"timestamp"]) -> None: ...

    FEATURES_FIELD_NUMBER: builtins.int
    ENTITY_ROWS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeatureReference]:
        """List of features that are being retrieved"""
    @property
    def entity_rows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetOnlineFeaturesRequest.EntityRow]:
        """List of entity rows, containing entity id and timestamp data.
        Used during retrieval of feature rows and for joining feature
        rows into a final dataset
        """
    project: builtins.str
    """Optional field to specify project name override. If specified, uses the
    given project for retrieval. Overrides the projects specified in
    Feature References if both are specified.
    """
    def __init__(
        self,
        *,
        features: collections.abc.Iterable[global___FeatureReference] | None = ...,
        entity_rows: collections.abc.Iterable[global___GetOnlineFeaturesRequest.EntityRow] | None = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_rows", b"entity_rows", "features", b"features", "project", b"project"]) -> None: ...

global___GetOnlineFeaturesRequest = GetOnlineFeaturesRequest

class GetOnlineFeaturesResponseV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class FieldValues(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class FieldsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            @property
            def value(self) -> feast.types.Value_pb2.Value: ...
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: feast.types.Value_pb2.Value | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        class StatusesEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: global___FieldStatus.ValueType
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: global___FieldStatus.ValueType = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        FIELDS_FIELD_NUMBER: builtins.int
        STATUSES_FIELD_NUMBER: builtins.int
        @property
        def fields(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, feast.types.Value_pb2.Value]:
            """Map of feature or entity name to feature/entity values.
            Timestamps are not returned in this response.
            """
        @property
        def statuses(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, global___FieldStatus.ValueType]:
            """Map of feature or entity name to feature/entity statuses/metadata."""
        def __init__(
            self,
            *,
            fields: collections.abc.Mapping[builtins.str, feast.types.Value_pb2.Value] | None = ...,
            statuses: collections.abc.Mapping[builtins.str, global___FieldStatus.ValueType] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["fields", b"fields", "statuses", b"statuses"]) -> None: ...

    FIELD_VALUES_FIELD_NUMBER: builtins.int
    @property
    def field_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetOnlineFeaturesResponseV2.FieldValues]:
        """Feature values retrieved from feast."""
    def __init__(
        self,
        *,
        field_values: collections.abc.Iterable[global___GetOnlineFeaturesResponseV2.FieldValues] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_values", b"field_values"]) -> None: ...

global___GetOnlineFeaturesResponseV2 = GetOnlineFeaturesResponseV2

class GetOnlineFeaturesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class FieldVector(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VALUES_FIELD_NUMBER: builtins.int
        STATUSES_FIELD_NUMBER: builtins.int
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[feast.types.Value_pb2.Value]: ...
        @property
        def statuses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___FieldStatus.ValueType]: ...
        def __init__(
            self,
            *,
            values: collections.abc.Iterable[feast.types.Value_pb2.Value] | None = ...,
            statuses: collections.abc.Iterable[global___FieldStatus.ValueType] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["statuses", b"statuses", "values", b"values"]) -> None: ...

    METADATA_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___GetOnlineFeaturesResponseMetadata: ...
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetOnlineFeaturesResponse.FieldVector]:
        """Length of "results" array should match length of requested features and entities.
        We also preserve the same order of features here as in metadata.field_names
        """
    def __init__(
        self,
        *,
        metadata: global___GetOnlineFeaturesResponseMetadata | None = ...,
        results: collections.abc.Iterable[global___GetOnlineFeaturesResponse.FieldVector] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "results", b"results"]) -> None: ...

global___GetOnlineFeaturesResponse = GetOnlineFeaturesResponse

class GetOnlineFeaturesResponseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAMES_FIELD_NUMBER: builtins.int
    @property
    def field_names(self) -> global___FieldList: ...
    def __init__(
        self,
        *,
        field_names: global___FieldList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["field_names", b"field_names"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_names", b"field_names"]) -> None: ...

global___GetOnlineFeaturesResponseMetadata = GetOnlineFeaturesResponseMetadata

class FieldList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAL_FIELD_NUMBER: builtins.int
    @property
    def val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        val: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["val", b"val"]) -> None: ...

global___FieldList = FieldList



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import feast.core.Entity_pb2
import feast.core.FeatureTable_pb2
import feast.core.Feature_pb2
import feast.core.OnlineStore_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetEntityRequest(google.protobuf.message.Message):
    """Request for a single entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of entity (required)."""
    project: builtins.str
    """Name of project the entity belongs to. If omitted will default to 'default' project."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "project", b"project"]) -> None: ...

global___GetEntityRequest = GetEntityRequest

class GetEntityResponse(google.protobuf.message.Message):
    """Response containing a single entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> feast.core.Entity_pb2.Entity: ...
    def __init__(
        self,
        *,
        entity: feast.core.Entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___GetEntityResponse = GetEntityResponse

class ListEntitiesRequest(google.protobuf.message.Message):
    """Retrieves details for all versions of a specific entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Filter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class LabelsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        PROJECT_FIELD_NUMBER: builtins.int
        LABELS_FIELD_NUMBER: builtins.int
        project: builtins.str
        """Optional. Specifies the name of the project to list Entities in.
        It is NOT possible to provide an asterisk with a string in order to do pattern matching.
        If unspecified, this field will default to the default project 'default'.
        """
        @property
        def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
            """Optional. User defined metadata for entity.
            Entities with all matching labels will be returned.
            """
        def __init__(
            self,
            *,
            project: builtins.str = ...,
            labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["labels", b"labels", "project", b"project"]) -> None: ...

    FILTER_FIELD_NUMBER: builtins.int
    @property
    def filter(self) -> global___ListEntitiesRequest.Filter: ...
    def __init__(
        self,
        *,
        filter: global___ListEntitiesRequest.Filter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> None: ...

global___ListEntitiesRequest = ListEntitiesRequest

class ListEntitiesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITIES_FIELD_NUMBER: builtins.int
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[feast.core.Entity_pb2.Entity]: ...
    def __init__(
        self,
        *,
        entities: collections.abc.Iterable[feast.core.Entity_pb2.Entity] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entities", b"entities"]) -> None: ...

global___ListEntitiesResponse = ListEntitiesResponse

class ListFeaturesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Filter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class LabelsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        LABELS_FIELD_NUMBER: builtins.int
        ENTITIES_FIELD_NUMBER: builtins.int
        PROJECT_FIELD_NUMBER: builtins.int
        @property
        def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
            """User defined metadata for feature.
            Features with all matching labels will be returned.
            """
        @property
        def entities(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """List of entities contained within the featureSet that the feature belongs to.
            Only feature tables with these entities will be searched for features.
            """
        project: builtins.str
        """Name of project that the feature tables belongs to. Filtering on projects is disabled. 
        It is NOT possible to provide an asterisk with a string in order to do pattern matching.
        If unspecified this field will default to the default project 'default'.
        """
        def __init__(
            self,
            *,
            labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
            entities: collections.abc.Iterable[builtins.str] | None = ...,
            project: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["entities", b"entities", "labels", b"labels", "project", b"project"]) -> None: ...

    FILTER_FIELD_NUMBER: builtins.int
    @property
    def filter(self) -> global___ListFeaturesRequest.Filter: ...
    def __init__(
        self,
        *,
        filter: global___ListFeaturesRequest.Filter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> None: ...

global___ListFeaturesRequest = ListFeaturesRequest

class ListFeaturesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class FeaturesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> feast.core.Feature_pb2.FeatureSpec: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: feast.core.Feature_pb2.FeatureSpec | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    FEATURES_FIELD_NUMBER: builtins.int
    @property
    def features(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, feast.core.Feature_pb2.FeatureSpec]: ...
    def __init__(
        self,
        *,
        features: collections.abc.Mapping[builtins.str, feast.core.Feature_pb2.FeatureSpec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["features", b"features"]) -> None: ...

global___ListFeaturesResponse = ListFeaturesResponse

class ApplyEntityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    @property
    def spec(self) -> feast.core.Entity_pb2.EntitySpec:
        """If project is unspecified, will default to 'default' project.
        If project specified does not exist, the project would be automatically created.
        """
    project: builtins.str
    """Name of project that this entity belongs to."""
    def __init__(
        self,
        *,
        spec: feast.core.Entity_pb2.EntitySpec | None = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project", b"project", "spec", b"spec"]) -> None: ...

global___ApplyEntityRequest = ApplyEntityRequest

class ApplyEntityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> feast.core.Entity_pb2.Entity: ...
    def __init__(
        self,
        *,
        entity: feast.core.Entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___ApplyEntityResponse = ApplyEntityResponse

class GetFeastCoreVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetFeastCoreVersionRequest = GetFeastCoreVersionRequest

class GetFeastCoreVersionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    def __init__(
        self,
        *,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["version", b"version"]) -> None: ...

global___GetFeastCoreVersionResponse = GetFeastCoreVersionResponse

class CreateProjectRequest(google.protobuf.message.Message):
    """Request to create a project"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of project (required)"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CreateProjectRequest = CreateProjectRequest

class CreateProjectResponse(google.protobuf.message.Message):
    """Response for creation of a project"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateProjectResponse = CreateProjectResponse

class ArchiveProjectRequest(google.protobuf.message.Message):
    """Request for the archival of a project"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of project to be archived"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ArchiveProjectRequest = ArchiveProjectRequest

class ArchiveProjectResponse(google.protobuf.message.Message):
    """Response for archival of a project"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ArchiveProjectResponse = ArchiveProjectResponse

class ListProjectsRequest(google.protobuf.message.Message):
    """Request for listing of projects"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListProjectsRequest = ListProjectsRequest

class ListProjectsResponse(google.protobuf.message.Message):
    """Response for listing of projects"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECTS_FIELD_NUMBER: builtins.int
    @property
    def projects(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of project names (archived projects are filtered out)"""
    def __init__(
        self,
        *,
        projects: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["projects", b"projects"]) -> None: ...

global___ListProjectsResponse = ListProjectsResponse

class ApplyFeatureTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_FIELD_NUMBER: builtins.int
    TABLE_SPEC_FIELD_NUMBER: builtins.int
    project: builtins.str
    """Optional. Name of the Project to apply the Feature Table to.
    If unspecified, will apply FeatureTable to the default project.
    """
    @property
    def table_spec(self) -> feast.core.FeatureTable_pb2.FeatureTableSpec:
        """Feature Table specification to apply"""
    def __init__(
        self,
        *,
        project: builtins.str = ...,
        table_spec: feast.core.FeatureTable_pb2.FeatureTableSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["table_spec", b"table_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project", b"project", "table_spec", b"table_spec"]) -> None: ...

global___ApplyFeatureTableRequest = ApplyFeatureTableRequest

class ApplyFeatureTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_FIELD_NUMBER: builtins.int
    @property
    def table(self) -> feast.core.FeatureTable_pb2.FeatureTable: ...
    def __init__(
        self,
        *,
        table: feast.core.FeatureTable_pb2.FeatureTable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["table", b"table"]) -> None: ...

global___ApplyFeatureTableResponse = ApplyFeatureTableResponse

class GetFeatureTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    project: builtins.str
    """Optional. Name of the Project to retrieve the Feature Table from.
    If unspecified, will apply FeatureTable to the default project.
    """
    name: builtins.str
    """Name of the FeatureTable to retrieve."""
    def __init__(
        self,
        *,
        project: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "project", b"project"]) -> None: ...

global___GetFeatureTableRequest = GetFeatureTableRequest

class GetFeatureTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_FIELD_NUMBER: builtins.int
    @property
    def table(self) -> feast.core.FeatureTable_pb2.FeatureTable:
        """The Feature Table retrieved."""
    def __init__(
        self,
        *,
        table: feast.core.FeatureTable_pb2.FeatureTable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["table", b"table"]) -> None: ...

global___GetFeatureTableResponse = GetFeatureTableResponse

class ListFeatureTablesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Filter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class LabelsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        PROJECT_FIELD_NUMBER: builtins.int
        LABELS_FIELD_NUMBER: builtins.int
        project: builtins.str
        """Optional. Specifies the name of the project to list Feature Tables in.
        If unspecified would list Feature Tables in the default project.
        """
        @property
        def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
            """Optional. Feature Tables with all matching labels will be returned.
            If unspecified would list Feature Tables without filtering by labels.
            """
        def __init__(
            self,
            *,
            project: builtins.str = ...,
            labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["labels", b"labels", "project", b"project"]) -> None: ...

    FILTER_FIELD_NUMBER: builtins.int
    @property
    def filter(self) -> global___ListFeatureTablesRequest.Filter:
        """Filter used when listing Feature Tables"""
    def __init__(
        self,
        *,
        filter: global___ListFeatureTablesRequest.Filter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> None: ...

global___ListFeatureTablesRequest = ListFeatureTablesRequest

class ListFeatureTablesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    @property
    def tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[feast.core.FeatureTable_pb2.FeatureTable]:
        """List of matching Feature Tables"""
    def __init__(
        self,
        *,
        tables: collections.abc.Iterable[feast.core.FeatureTable_pb2.FeatureTable] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tables", b"tables"]) -> None: ...

global___ListFeatureTablesResponse = ListFeatureTablesResponse

class DeleteFeatureTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    project: builtins.str
    """Optional. Name of the Project to delete the Feature Table from.
    If unspecified, will delete FeatureTable from the default project.
    """
    name: builtins.str
    """Name of the FeatureTable to delete."""
    def __init__(
        self,
        *,
        project: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "project", b"project"]) -> None: ...

global___DeleteFeatureTableRequest = DeleteFeatureTableRequest

class DeleteFeatureTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteFeatureTableResponse = DeleteFeatureTableResponse

class ListOnlineStoresRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListOnlineStoresRequest = ListOnlineStoresRequest

class ListOnlineStoresResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_STORE_FIELD_NUMBER: builtins.int
    @property
    def online_store(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[feast.core.OnlineStore_pb2.OnlineStore]: ...
    def __init__(
        self,
        *,
        online_store: collections.abc.Iterable[feast.core.OnlineStore_pb2.OnlineStore] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["online_store", b"online_store"]) -> None: ...

global___ListOnlineStoresResponse = ListOnlineStoresResponse

class GetOnlineStoreRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___GetOnlineStoreRequest = GetOnlineStoreRequest

class GetOnlineStoreResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GetOnlineStoreResponse._Status.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTIVE: GetOnlineStoreResponse._Status.ValueType  # 0
        """Requested online store is active"""
        ARCHIVED: GetOnlineStoreResponse._Status.ValueType  # 1
        """Requested online store is archived"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    ACTIVE: GetOnlineStoreResponse.Status.ValueType  # 0
    """Requested online store is active"""
    ARCHIVED: GetOnlineStoreResponse.Status.ValueType  # 1
    """Requested online store is archived"""

    ONLINE_STORE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def online_store(self) -> feast.core.OnlineStore_pb2.OnlineStore: ...
    status: global___GetOnlineStoreResponse.Status.ValueType
    def __init__(
        self,
        *,
        online_store: feast.core.OnlineStore_pb2.OnlineStore | None = ...,
        status: global___GetOnlineStoreResponse.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["online_store", b"online_store"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["online_store", b"online_store", "status", b"status"]) -> None: ...

global___GetOnlineStoreResponse = GetOnlineStoreResponse

class RegisterOnlineStoreRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_STORE_FIELD_NUMBER: builtins.int
    @property
    def online_store(self) -> feast.core.OnlineStore_pb2.OnlineStore: ...
    def __init__(
        self,
        *,
        online_store: feast.core.OnlineStore_pb2.OnlineStore | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["online_store", b"online_store"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["online_store", b"online_store"]) -> None: ...

global___RegisterOnlineStoreRequest = RegisterOnlineStoreRequest

class RegisterOnlineStoreResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RegisterOnlineStoreResponse._Status.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NO_CHANGE: RegisterOnlineStoreResponse._Status.ValueType  # 0
        """Existing store properties matching the given online store is identical to the given request"""
        REGISTERED: RegisterOnlineStoreResponse._Status.ValueType  # 1
        """New online store created or existing properties updated."""
        UPDATED: RegisterOnlineStoreResponse._Status.ValueType  # 2
        """Existing online store updated."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    NO_CHANGE: RegisterOnlineStoreResponse.Status.ValueType  # 0
    """Existing store properties matching the given online store is identical to the given request"""
    REGISTERED: RegisterOnlineStoreResponse.Status.ValueType  # 1
    """New online store created or existing properties updated."""
    UPDATED: RegisterOnlineStoreResponse.Status.ValueType  # 2
    """Existing online store updated."""

    ONLINE_STORE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def online_store(self) -> feast.core.OnlineStore_pb2.OnlineStore: ...
    status: global___RegisterOnlineStoreResponse.Status.ValueType
    def __init__(
        self,
        *,
        online_store: feast.core.OnlineStore_pb2.OnlineStore | None = ...,
        status: global___RegisterOnlineStoreResponse.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["online_store", b"online_store"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["online_store", b"online_store", "status", b"status"]) -> None: ...

global___RegisterOnlineStoreResponse = RegisterOnlineStoreResponse

class ArchiveOnlineStoreRequest(google.protobuf.message.Message):
    """Request for the archival of an online store"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of online store to be archived"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ArchiveOnlineStoreRequest = ArchiveOnlineStoreRequest

class ArchiveOnlineStoreResponse(google.protobuf.message.Message):
    """Response for archival of an online store"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ArchiveOnlineStoreResponse = ArchiveOnlineStoreResponse



import grpc
from datetime import datetime
from dataclasses import dataclass
from feast.core.CoreService_pb2_grpc import CoreServiceStub
from feast.core.CoreService_pb2 import (
    ListOnlineStoresRequest,
    ListOnlineStoresResponse,
    GetFeatureTableRequest,
    GetFeatureTableResponse
)
from feast.core.FeatureTable_pb2 import FeatureTableSpec
from feast_spark.api.JobService_pb2 import (
    StartOfflineToOnlineIngestionJobRequest,
    StartOfflineToOnlineIngestionJobResponse
)
from feast_spark.api.JobService_pb2_grpc import JobServiceStub

@dataclass
class Client:
    registry_url: str
    project: str = None
    _core_service_stub: CoreServiceStub = None
    _job_service_stub: JobServiceStub = None

    @property
    def _core_service(self):
        """
        Creates or returns the gRPC Feast Core Service Stub

        Returns: CoreServiceStub
        """
        if not self._core_service_stub:
            channel = grpc.insecure_channel(self.registry_url)
            self._core_service_stub = CoreServiceStub(channel)
        return self._core_service_stub

    @property
    def _job_service(self):
        """
        Creates or returns the gRPC Feast Job Service Stub

        Returns: JobServiceStub
        """
        if not self._job_service_stub:
            channel = grpc.insecure_channel(self.registry_url)
            self._job_service_stub = JobServiceStub(channel)
        return self._job_service_stub

    def list_online_stores(self) -> ListOnlineStoresResponse:
        try:
            response = self._core_service.ListOnlineStores(ListOnlineStoresRequest())
        except grpc.RpcError:
            raise
        return response

    def start_offline_to_online_ingestion(
        self, feature_table: str, start: datetime, end: datetime, project: str = None, delta_ingestion: bool = False
    ) -> StartOfflineToOnlineIngestionJobResponse:

        if project is None:
            project = self.project

        request = StartOfflineToOnlineIngestionJobRequest(
            project=project, table_name=feature_table, delta_ingestion=delta_ingestion
        )
        request.start_date.FromDatetime(start)
        request.end_date.FromDatetime(end)
        try:
            response = self._job_service.StartOfflineToOnlineIngestionJob(request)
        except grpc.RpcError:
            raise
        return response

    def get_feature_table(self, name: str, project: str = None) -> FeatureTableSpec:
        """
        Retrieves a feature table.

        Args:
            project: Feast project that this feature table belongs to
            name: Name of feature table

        Returns:
            Returns either the requested feature table spec or raises an exception if
            none is found
        """

        if project is None:
            project = self.project

        try:
            response = self._core_service.GetFeatureTable(
                GetFeatureTableRequest(project=project, name=name.strip()),
            )
        except grpc.RpcError:
            raise
        return response.table.spec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import feast.types.Value_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Entity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    @property
    def spec(self) -> global___EntitySpec:
        """User-specified specifications of this entity."""
    @property
    def meta(self) -> global___EntityMeta:
        """System-populated metadata for this entity."""
    def __init__(
        self,
        *,
        spec: global___EntitySpec | None = ...,
        meta: global___EntityMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta", b"meta", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["meta", b"meta", "spec", b"spec"]) -> None: ...

global___Entity = Entity

class EntitySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the entity."""
    value_type: feast.types.Value_pb2.ValueType.Enum.ValueType
    """Type of the entity."""
    description: builtins.str
    """Description of the entity."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """User defined metadata"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value_type: feast.types.Value_pb2.ValueType.Enum.ValueType = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "labels", b"labels", "name", b"name", "value_type", b"value_type"]) -> None: ...

global___EntitySpec = EntitySpec

class EntityMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_UPDATED_TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def created_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_updated_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        created_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_updated_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_timestamp", b"created_timestamp", "last_updated_timestamp", b"last_updated_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_timestamp", b"created_timestamp", "last_updated_timestamp", b"last_updated_timestamp"]) -> None: ...

global___EntityMeta = EntityMeta



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from feast.core import CoreService_pb2 as feast_dot_core_dot_CoreService__pb2


class CoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFeastCoreVersion = channel.unary_unary(
                '/feast.core.CoreService/GetFeastCoreVersion',
                request_serializer=feast_dot_core_dot_CoreService__pb2.GetFeastCoreVersionRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.GetFeastCoreVersionResponse.FromString,
                )
        self.GetEntity = channel.unary_unary(
                '/feast.core.CoreService/GetEntity',
                request_serializer=feast_dot_core_dot_CoreService__pb2.GetEntityRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.GetEntityResponse.FromString,
                )
        self.ListFeatures = channel.unary_unary(
                '/feast.core.CoreService/ListFeatures',
                request_serializer=feast_dot_core_dot_CoreService__pb2.ListFeaturesRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.ListFeaturesResponse.FromString,
                )
        self.ApplyEntity = channel.unary_unary(
                '/feast.core.CoreService/ApplyEntity',
                request_serializer=feast_dot_core_dot_CoreService__pb2.ApplyEntityRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.ApplyEntityResponse.FromString,
                )
        self.ListEntities = channel.unary_unary(
                '/feast.core.CoreService/ListEntities',
                request_serializer=feast_dot_core_dot_CoreService__pb2.ListEntitiesRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.ListEntitiesResponse.FromString,
                )
        self.CreateProject = channel.unary_unary(
                '/feast.core.CoreService/CreateProject',
                request_serializer=feast_dot_core_dot_CoreService__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.CreateProjectResponse.FromString,
                )
        self.ArchiveProject = channel.unary_unary(
                '/feast.core.CoreService/ArchiveProject',
                request_serializer=feast_dot_core_dot_CoreService__pb2.ArchiveProjectRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.ArchiveProjectResponse.FromString,
                )
        self.ListProjects = channel.unary_unary(
                '/feast.core.CoreService/ListProjects',
                request_serializer=feast_dot_core_dot_CoreService__pb2.ListProjectsRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.ListProjectsResponse.FromString,
                )
        self.ApplyFeatureTable = channel.unary_unary(
                '/feast.core.CoreService/ApplyFeatureTable',
                request_serializer=feast_dot_core_dot_CoreService__pb2.ApplyFeatureTableRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.ApplyFeatureTableResponse.FromString,
                )
        self.ListFeatureTables = channel.unary_unary(
                '/feast.core.CoreService/ListFeatureTables',
                request_serializer=feast_dot_core_dot_CoreService__pb2.ListFeatureTablesRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.ListFeatureTablesResponse.FromString,
                )
        self.GetFeatureTable = channel.unary_unary(
                '/feast.core.CoreService/GetFeatureTable',
                request_serializer=feast_dot_core_dot_CoreService__pb2.GetFeatureTableRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.GetFeatureTableResponse.FromString,
                )
        self.DeleteFeatureTable = channel.unary_unary(
                '/feast.core.CoreService/DeleteFeatureTable',
                request_serializer=feast_dot_core_dot_CoreService__pb2.DeleteFeatureTableRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.DeleteFeatureTableResponse.FromString,
                )
        self.ListOnlineStores = channel.unary_unary(
                '/feast.core.CoreService/ListOnlineStores',
                request_serializer=feast_dot_core_dot_CoreService__pb2.ListOnlineStoresRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.ListOnlineStoresResponse.FromString,
                )
        self.GetOnlineStore = channel.unary_unary(
                '/feast.core.CoreService/GetOnlineStore',
                request_serializer=feast_dot_core_dot_CoreService__pb2.GetOnlineStoreRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.GetOnlineStoreResponse.FromString,
                )
        self.RegisterOnlineStore = channel.unary_unary(
                '/feast.core.CoreService/RegisterOnlineStore',
                request_serializer=feast_dot_core_dot_CoreService__pb2.RegisterOnlineStoreRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.RegisterOnlineStoreResponse.FromString,
                )
        self.ArchiveOnlineStore = channel.unary_unary(
                '/feast.core.CoreService/ArchiveOnlineStore',
                request_serializer=feast_dot_core_dot_CoreService__pb2.ArchiveOnlineStoreRequest.SerializeToString,
                response_deserializer=feast_dot_core_dot_CoreService__pb2.ArchiveOnlineStoreResponse.FromString,
                )


class CoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFeastCoreVersion(self, request, context):
        """Retrieve version information about this Feast deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEntity(self, request, context):
        """Returns a specific entity
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatures(self, request, context):
        """Returns all feature references and respective features matching that filter. If none are found
        an empty map will be returned
        If no filter is provided in the request, the response will contain all the features
        currently stored in the default project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyEntity(self, request, context):
        """Create or update and existing entity.

        This function is idempotent - it will not create a new entity if schema does not change.
        Schema changes will update the entity if the changes are valid.
        Following changes are not valid:
        - Changes to name
        - Changes to type
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEntities(self, request, context):
        """Returns all entity references and respective entities matching that filter. If none are found
        an empty map will be returned
        If no filter is provided in the request, the response will contain all the entities
        currently stored in the default project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateProject(self, request, context):
        """Creates a project. Projects serve as namespaces within which resources like features will be
        created. Feature table names as must be unique within a project while field (Feature/Entity) names
        must be unique within a Feature Table. Project names themselves must be globally unique.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchiveProject(self, request, context):
        """Archives a project. Archived projects will continue to exist and function, but won't be visible
        through the Core API. Any existing ingestion or serving requests will continue to function,
        but will result in warning messages being logged. It is not possible to unarchive a project
        through the Core API
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjects(self, request, context):
        """Lists all projects active projects.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyFeatureTable(self, request, context):
        """Feature Tables 

        Create or update an existing feature table.
        This function is idempotent - it will not create a new feature table if the schema does not change.
        Schema changes will update the feature table if the changes are valid.
        All changes except the following are valid:
        - Changes to feature table name.
        - Changes to entities
        - Changes to feature name and type
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureTables(self, request, context):
        """List feature tables that match a given filter.
        Returns the references of the Feature Tables matching that filter. If none are found,
        an empty list will be returned.
        If no filter is provided in the request, the response will match all the feature
        tables currently stored in the registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureTable(self, request, context):
        """Returns a specific feature table
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureTable(self, request, context):
        """Delete a specific feature table
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOnlineStores(self, request, context):
        """Lists all online stores
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOnlineStore(self, request, context):
        """Returns a specific online stores
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterOnlineStore(self, request, context):
        """Registers new online store to feast core
        or updates properties for existing online store
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchiveOnlineStore(self, request, context):
        """Archives an online store to mark it deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFeastCoreVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeastCoreVersion,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.GetFeastCoreVersionRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.GetFeastCoreVersionResponse.SerializeToString,
            ),
            'GetEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEntity,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.GetEntityRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.GetEntityResponse.SerializeToString,
            ),
            'ListFeatures': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatures,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.ListFeaturesRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.ListFeaturesResponse.SerializeToString,
            ),
            'ApplyEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyEntity,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.ApplyEntityRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.ApplyEntityResponse.SerializeToString,
            ),
            'ListEntities': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEntities,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.ListEntitiesRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.ListEntitiesResponse.SerializeToString,
            ),
            'CreateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProject,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.CreateProjectRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.CreateProjectResponse.SerializeToString,
            ),
            'ArchiveProject': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchiveProject,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.ArchiveProjectRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.ArchiveProjectResponse.SerializeToString,
            ),
            'ListProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjects,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.ListProjectsRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.ListProjectsResponse.SerializeToString,
            ),
            'ApplyFeatureTable': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyFeatureTable,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.ApplyFeatureTableRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.ApplyFeatureTableResponse.SerializeToString,
            ),
            'ListFeatureTables': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureTables,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.ListFeatureTablesRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.ListFeatureTablesResponse.SerializeToString,
            ),
            'GetFeatureTable': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureTable,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.GetFeatureTableRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.GetFeatureTableResponse.SerializeToString,
            ),
            'DeleteFeatureTable': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureTable,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.DeleteFeatureTableRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.DeleteFeatureTableResponse.SerializeToString,
            ),
            'ListOnlineStores': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOnlineStores,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.ListOnlineStoresRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.ListOnlineStoresResponse.SerializeToString,
            ),
            'GetOnlineStore': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOnlineStore,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.GetOnlineStoreRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.GetOnlineStoreResponse.SerializeToString,
            ),
            'RegisterOnlineStore': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterOnlineStore,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.RegisterOnlineStoreRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.RegisterOnlineStoreResponse.SerializeToString,
            ),
            'ArchiveOnlineStore': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchiveOnlineStore,
                    request_deserializer=feast_dot_core_dot_CoreService__pb2.ArchiveOnlineStoreRequest.FromString,
                    response_serializer=feast_dot_core_dot_CoreService__pb2.ArchiveOnlineStoreResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'feast.core.CoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFeastCoreVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/GetFeastCoreVersion',
            feast_dot_core_dot_CoreService__pb2.GetFeastCoreVersionRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.GetFeastCoreVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/GetEntity',
            feast_dot_core_dot_CoreService__pb2.GetEntityRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.GetEntityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatures(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/ListFeatures',
            feast_dot_core_dot_CoreService__pb2.ListFeaturesRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.ListFeaturesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/ApplyEntity',
            feast_dot_core_dot_CoreService__pb2.ApplyEntityRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.ApplyEntityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEntities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/ListEntities',
            feast_dot_core_dot_CoreService__pb2.ListEntitiesRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.ListEntitiesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/CreateProject',
            feast_dot_core_dot_CoreService__pb2.CreateProjectRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.CreateProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchiveProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/ArchiveProject',
            feast_dot_core_dot_CoreService__pb2.ArchiveProjectRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.ArchiveProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/ListProjects',
            feast_dot_core_dot_CoreService__pb2.ListProjectsRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.ListProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyFeatureTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/ApplyFeatureTable',
            feast_dot_core_dot_CoreService__pb2.ApplyFeatureTableRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.ApplyFeatureTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/ListFeatureTables',
            feast_dot_core_dot_CoreService__pb2.ListFeatureTablesRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.ListFeatureTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/GetFeatureTable',
            feast_dot_core_dot_CoreService__pb2.GetFeatureTableRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.GetFeatureTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/DeleteFeatureTable',
            feast_dot_core_dot_CoreService__pb2.DeleteFeatureTableRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.DeleteFeatureTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOnlineStores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/ListOnlineStores',
            feast_dot_core_dot_CoreService__pb2.ListOnlineStoresRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.ListOnlineStoresResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOnlineStore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/GetOnlineStore',
            feast_dot_core_dot_CoreService__pb2.GetOnlineStoreRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.GetOnlineStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterOnlineStore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/RegisterOnlineStore',
            feast_dot_core_dot_CoreService__pb2.RegisterOnlineStoreRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.RegisterOnlineStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchiveOnlineStore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/feast.core.CoreService/ArchiveOnlineStore',
            feast_dot_core_dot_CoreService__pb2.ArchiveOnlineStoreRequest.SerializeToString,
            feast_dot_core_dot_CoreService__pb2.ArchiveOnlineStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ValueType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Enum:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnumEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ValueType._Enum.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID: ValueType._Enum.ValueType  # 0
        BYTES: ValueType._Enum.ValueType  # 1
        STRING: ValueType._Enum.ValueType  # 2
        INT32: ValueType._Enum.ValueType  # 3
        INT64: ValueType._Enum.ValueType  # 4
        DOUBLE: ValueType._Enum.ValueType  # 5
        FLOAT: ValueType._Enum.ValueType  # 6
        BOOL: ValueType._Enum.ValueType  # 7
        BYTES_LIST: ValueType._Enum.ValueType  # 11
        STRING_LIST: ValueType._Enum.ValueType  # 12
        INT32_LIST: ValueType._Enum.ValueType  # 13
        INT64_LIST: ValueType._Enum.ValueType  # 14
        DOUBLE_LIST: ValueType._Enum.ValueType  # 15
        FLOAT_LIST: ValueType._Enum.ValueType  # 16
        BOOL_LIST: ValueType._Enum.ValueType  # 17

    class Enum(_Enum, metaclass=_EnumEnumTypeWrapper): ...
    INVALID: ValueType.Enum.ValueType  # 0
    BYTES: ValueType.Enum.ValueType  # 1
    STRING: ValueType.Enum.ValueType  # 2
    INT32: ValueType.Enum.ValueType  # 3
    INT64: ValueType.Enum.ValueType  # 4
    DOUBLE: ValueType.Enum.ValueType  # 5
    FLOAT: ValueType.Enum.ValueType  # 6
    BOOL: ValueType.Enum.ValueType  # 7
    BYTES_LIST: ValueType.Enum.ValueType  # 11
    STRING_LIST: ValueType.Enum.ValueType  # 12
    INT32_LIST: ValueType.Enum.ValueType  # 13
    INT64_LIST: ValueType.Enum.ValueType  # 14
    DOUBLE_LIST: ValueType.Enum.ValueType  # 15
    FLOAT_LIST: ValueType.Enum.ValueType  # 16
    BOOL_LIST: ValueType.Enum.ValueType  # 17

    def __init__(
        self,
    ) -> None: ...

global___ValueType = ValueType

class Value(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYTES_VAL_FIELD_NUMBER: builtins.int
    STRING_VAL_FIELD_NUMBER: builtins.int
    INT32_VAL_FIELD_NUMBER: builtins.int
    INT64_VAL_FIELD_NUMBER: builtins.int
    DOUBLE_VAL_FIELD_NUMBER: builtins.int
    FLOAT_VAL_FIELD_NUMBER: builtins.int
    BOOL_VAL_FIELD_NUMBER: builtins.int
    BYTES_LIST_VAL_FIELD_NUMBER: builtins.int
    STRING_LIST_VAL_FIELD_NUMBER: builtins.int
    INT32_LIST_VAL_FIELD_NUMBER: builtins.int
    INT64_LIST_VAL_FIELD_NUMBER: builtins.int
    DOUBLE_LIST_VAL_FIELD_NUMBER: builtins.int
    FLOAT_LIST_VAL_FIELD_NUMBER: builtins.int
    BOOL_LIST_VAL_FIELD_NUMBER: builtins.int
    bytes_val: builtins.bytes
    string_val: builtins.str
    int32_val: builtins.int
    int64_val: builtins.int
    double_val: builtins.float
    float_val: builtins.float
    bool_val: builtins.bool
    @property
    def bytes_list_val(self) -> global___BytesList: ...
    @property
    def string_list_val(self) -> global___StringList: ...
    @property
    def int32_list_val(self) -> global___Int32List: ...
    @property
    def int64_list_val(self) -> global___Int64List: ...
    @property
    def double_list_val(self) -> global___DoubleList: ...
    @property
    def float_list_val(self) -> global___FloatList: ...
    @property
    def bool_list_val(self) -> global___BoolList: ...
    def __init__(
        self,
        *,
        bytes_val: builtins.bytes = ...,
        string_val: builtins.str = ...,
        int32_val: builtins.int = ...,
        int64_val: builtins.int = ...,
        double_val: builtins.float = ...,
        float_val: builtins.float = ...,
        bool_val: builtins.bool = ...,
        bytes_list_val: global___BytesList | None = ...,
        string_list_val: global___StringList | None = ...,
        int32_list_val: global___Int32List | None = ...,
        int64_list_val: global___Int64List | None = ...,
        double_list_val: global___DoubleList | None = ...,
        float_list_val: global___FloatList | None = ...,
        bool_list_val: global___BoolList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bool_list_val", b"bool_list_val", "bool_val", b"bool_val", "bytes_list_val", b"bytes_list_val", "bytes_val", b"bytes_val", "double_list_val", b"double_list_val", "double_val", b"double_val", "float_list_val", b"float_list_val", "float_val", b"float_val", "int32_list_val", b"int32_list_val", "int32_val", b"int32_val", "int64_list_val", b"int64_list_val", "int64_val", b"int64_val", "string_list_val", b"string_list_val", "string_val", b"string_val", "val", b"val"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bool_list_val", b"bool_list_val", "bool_val", b"bool_val", "bytes_list_val", b"bytes_list_val", "bytes_val", b"bytes_val", "double_list_val", b"double_list_val", "double_val", b"double_val", "float_list_val", b"float_list_val", "float_val", b"float_val", "int32_list_val", b"int32_list_val", "int32_val", b"int32_val", "int64_list_val", b"int64_list_val", "int64_val", b"int64_val", "string_list_val", b"string_list_val", "string_val", b"string_val", "val", b"val"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["val", b"val"]) -> typing_extensions.Literal["bytes_val", "string_val", "int32_val", "int64_val", "double_val", "float_val", "bool_val", "bytes_list_val", "string_list_val", "int32_list_val", "int64_list_val", "double_list_val", "float_list_val", "bool_list_val"] | None: ...

global___Value = Value

class BytesList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAL_FIELD_NUMBER: builtins.int
    @property
    def val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
    def __init__(
        self,
        *,
        val: collections.abc.Iterable[builtins.bytes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["val", b"val"]) -> None: ...

global___BytesList = BytesList

class StringList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAL_FIELD_NUMBER: builtins.int
    @property
    def val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        val: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["val", b"val"]) -> None: ...

global___StringList = StringList

class Int32List(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAL_FIELD_NUMBER: builtins.int
    @property
    def val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        val: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["val", b"val"]) -> None: ...

global___Int32List = Int32List

class Int64List(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAL_FIELD_NUMBER: builtins.int
    @property
    def val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        val: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["val", b"val"]) -> None: ...

global___Int64List = Int64List

class DoubleList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAL_FIELD_NUMBER: builtins.int
    @property
    def val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        val: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["val", b"val"]) -> None: ...

global___DoubleList = DoubleList

class FloatList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAL_FIELD_NUMBER: builtins.int
    @property
    def val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        val: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["val", b"val"]) -> None: ...

global___FloatList = FloatList

class BoolList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAL_FIELD_NUMBER: builtins.int
    @property
    def val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    def __init__(
        self,
        *,
        val: collections.abc.Iterable[builtins.bool] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["val", b"val"]) -> None: ...

global___BoolList = BoolList



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feast/types/Value.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x66\x65\x61st/types/Value.proto\x12\x0b\x66\x65\x61st.types\"\xe0\x01\n\tValueType\"\xd2\x01\n\x04\x45num\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05\x42YTES\x10\x01\x12\n\n\x06STRING\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\t\n\x05\x46LOAT\x10\x06\x12\x08\n\x04\x42OOL\x10\x07\x12\x0e\n\nBYTES_LIST\x10\x0b\x12\x0f\n\x0bSTRING_LIST\x10\x0c\x12\x0e\n\nINT32_LIST\x10\r\x12\x0e\n\nINT64_LIST\x10\x0e\x12\x0f\n\x0b\x44OUBLE_LIST\x10\x0f\x12\x0e\n\nFLOAT_LIST\x10\x10\x12\r\n\tBOOL_LIST\x10\x11\"\x82\x04\n\x05Value\x12\x13\n\tbytes_val\x18\x01 \x01(\x0cH\x00\x12\x14\n\nstring_val\x18\x02 \x01(\tH\x00\x12\x13\n\tint32_val\x18\x03 \x01(\x05H\x00\x12\x13\n\tint64_val\x18\x04 \x01(\x03H\x00\x12\x14\n\ndouble_val\x18\x05 \x01(\x01H\x00\x12\x13\n\tfloat_val\x18\x06 \x01(\x02H\x00\x12\x12\n\x08\x62ool_val\x18\x07 \x01(\x08H\x00\x12\x30\n\x0e\x62ytes_list_val\x18\x0b \x01(\x0b\x32\x16.feast.types.BytesListH\x00\x12\x32\n\x0fstring_list_val\x18\x0c \x01(\x0b\x32\x17.feast.types.StringListH\x00\x12\x30\n\x0eint32_list_val\x18\r \x01(\x0b\x32\x16.feast.types.Int32ListH\x00\x12\x30\n\x0eint64_list_val\x18\x0e \x01(\x0b\x32\x16.feast.types.Int64ListH\x00\x12\x32\n\x0f\x64ouble_list_val\x18\x0f \x01(\x0b\x32\x17.feast.types.DoubleListH\x00\x12\x30\n\x0e\x66loat_list_val\x18\x10 \x01(\x0b\x32\x16.feast.types.FloatListH\x00\x12.\n\rbool_list_val\x18\x11 \x01(\x0b\x32\x15.feast.types.BoolListH\x00\x42\x05\n\x03val\"\x18\n\tBytesList\x12\x0b\n\x03val\x18\x01 \x03(\x0c\"\x19\n\nStringList\x12\x0b\n\x03val\x18\x01 \x03(\t\"\x18\n\tInt32List\x12\x0b\n\x03val\x18\x01 \x03(\x05\"\x18\n\tInt64List\x12\x0b\n\x03val\x18\x01 \x03(\x03\"\x19\n\nDoubleList\x12\x0b\n\x03val\x18\x01 \x03(\x01\"\x18\n\tFloatList\x12\x0b\n\x03val\x18\x01 \x03(\x02\"\x17\n\x08\x42oolList\x12\x0b\n\x03val\x18\x01 \x03(\x08\x42-\n\x1f\x64\x65v.caraml.store.protobuf.typesB\nValueProtob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feast.types.Value_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037dev.caraml.store.protobuf.typesB\nValueProto'
  _VALUETYPE._serialized_start=41
  _VALUETYPE._serialized_end=265
  _VALUETYPE_ENUM._serialized_start=55
  _VALUETYPE_ENUM._serialized_end=265
  _VALUE._serialized_start=268
  _VALUE._serialized_end=782
  _BYTESLIST._serialized_start=784
  _BYTESLIST._serialized_end=808
  _STRINGLIST._serialized_start=810
  _STRINGLIST._serialized_end=835
  _INT32LIST._serialized_start=837
  _INT32LIST._serialized_end=861
  _INT64LIST._serialized_start=863
  _INT64LIST._serialized_end=887
  _DOUBLELIST._serialized_start=889
  _DOUBLELIST._serialized_end=914
  _FLOATLIST._serialized_start=916
  _FLOATLIST._serialized_end=940
  _BOOLLIST._serialized_start=942
  _BOOLLIST._serialized_end=965
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Legacy compatibility endpoint for older version of feast client.
The new endpoint is defined in feast_spark/api/JobService.proto
"""
import google.protobuf.descriptor

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor
